; Configuration file for Duet 3 (firmware version 3)
; executed by the firmware on start-up
;
; generated by Ben Levi - BLV developer as a basic version

; ================ General preferences ============
G90                                                ; send absolute coordinates...
M83                                                ; ...but relative extruder moves
M550 P"BLV mgn Cube"                                   ; set printer name
M669 K1                                            ; select CoreXY mode

; ================ Network ========================
M552 P0.0.0.0 S1                                   ; enable network and acquire dynamic address via DHCP
M586 P0 S1                                         ; enable HTTP
M586 P1 S0                                         ; disable FTP
M586 P2 S0                                         ; disable Telnet

; ================ Drives mapping =================
M569 P0.1 S0                                       ; physical drive 0.1 goes forwards - X driver
M569 P0.2 S0                                       ; physical drive 0.2 goes forwards - Y driver
M569 P0.3 S1                                       ; physical drive 0.3 goes forwards - Z1 Right driver
M569 P0.4 S1                                       ; physical drive 0.4 goes forwards - Z2 Left driver
M569 P0.0 S0                                       ; physical drive 0.0 goes forwards - extruder driver
M584 X0.1 Y0.2 Z0.3:0.4 E0.0                       ; set drive mapping

; ================ Drives settings ================
M350 X16 Y16 Z16 E16 I1                            ; configure microstepping with interpolation
M92 X200.00 Y200.00 Z400.00 E917.444               ; set steps per mm - for Matrix extruder:E324.214
M566 X700.00 Y700.00 Z24.00 E2000.00               ; set maximum instantaneous speed changes (mm/min)
M203 X35000.00 Y35000.00 Z1200.00 E5000.00         ; set maximum speeds (mm/min)
M201 X6000.00 Y6000.00 Z400.00 E2500.00            ; set accelerations (mm/s^2)
M906 X1600 Y1600 Z1600:1600 E1000 I30              ; set motor currents (mA) and motor idle factor in per cent
M84 S60                                            ; Set idle timeout

; ================ Independent Z leveling (original 2 z-axis) =================
M671 X369.75:-59.75 Y155:155 S5					   ; Define positions of Z leadscrews for Independent Z leveling

; ================ Axis Limits ====================
M208 X-35.5 Y0 Z0 S1                                 ; set axis minima
M208 X320 Y326.8 Z340 S0                             ; set axis maxima

; ================ Endstops =======================
M574 X1 S1 P"io0.in"                               ; configure active-high endstop for low end on X via pin io0.in
M574 Y2 S1 P"io1.in"                               ; configure active-high endstop for low end on Y via pin io1.in
M574 Z1 S2                                         ; configure Z-probe endstop for low end on Z

; ================ Z-Probe ========================
M558 P5 C"^!io2.in" A2 H5 F120 T15000              ; set Z probe type to unmodulated and the dive height + speeds (for Mini IR sensor M558 P8 C"io2.in" A2 H5 F120 T15000) 
G31 P50 X11.5 Y65.8 Z1.035	                   ; set Z probe trigger value, offset and trigger height Z1.023
M556 S50 X0 Y0 Z0                                  ; set orthogonal axis compensation parameters
M557 X30:270 Y30:270 P4                            ; define mesh grid

; ================ Heaters ==============================================
M308 S0 P"temp0" Y"thermistor" A"Bed" T100000 B3950       				 ; configure sensor 0 as thermistor on pin temp0
M950 H0 Q10 C"out1" T0                                					 ; create bed heater output on out0 and map it to sensor 0 (if NOT using SSR - delete Q10)
M307 H0 R0.928 C350.9 D6.77 S1.00 V24.0                              	 ; disable bang-bang mode for the bed heater and set PWM limit
M140 H0                                            						 ; map heated bed to heater 0
M143 H0 S100                                     						 ; set temperature limit for heater 0 to 100C
M308 S1 P"temp1" Y"thermistor" A"Hotend" T107537 B4725 C7.06e-8	 		 ; configure sensor 1 as thermistor on pin temp1
M950 H1 C"out2" T1                                						 ; create nozzle heater output on out1 and map it to sensor 1
M307 H1 R1.953 C374.1 D8.85 S1.00 V24.0       							 ; disable bang-bang mode for heater  and set PWM limit 
M143 H1 S280                                       						 ; set temperature limit for heater 1 to 280C

; ================ Fans & Lights ==================
M950 F0 C"out7" Q500 				               ; create fan 0 on pin out7 and set its frequency
M106 P0 S0 H1 T35                                  ; set fan 0 value. Thermostatic control is turned on
M950 F1 C"out8" Q500                               ; create fan 1 on pin out8 and set its frequency
M106 P1 S0 H-1 C"Layers Fan"                       ; set fan 1 value. Thermostatic control is turned off 
M950 F2 C"out9" Q500                               ; create fan 2 on pin out9 and set its frequency (lights)
M106 P2 S0.2 H-1 C"Lights"                         ; set fan 2 value. Thermostatic control is turned off (lights)

; ================ Tools ==========================
M563 P0 D0 H1 F0:1                                 ; define tool 0
G10 P0 X0 Y0 Z0                                    ; set tool 0 axis offsets
G10 P0 R0 S0                                       ; set initial tool 0 active and standby temperatures to 0C

; ================ Miscellaneous ==================
;M575 P1 S1 B57600                                  ; enable support for PanelDue
M911 S10 R11 P"M913 X0 Y0 G91 M83 G1 Z3 E-5 F1000" ; set voltage thresholds and actions to run on power loss

